==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
export let RenderRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RenderRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
                RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.j(RenderRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Animate", "Boolean");
        }
        static d(a) {
            RenderRequestedEventArgsDescriptionMetadata.b(a);
            a.aa("RenderRequestedEventArgs", () => new RenderRequestedEventArgsDescription());
            a.z("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
        }
    }
    RenderRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
export let RenderRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RenderRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
                RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RenderRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Animate", "Boolean");
        }
        static d(a) {
            RenderRequestedEventArgsDescriptionMetadata.b(a);
            a.ac("RenderRequestedEventArgs", () => new RenderRequestedEventArgsDescription());
            a.ab("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
        }
    }
    RenderRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
})();
